=========
Changelog
=========

0.2.1 (2017-04-17)
==================

- Add PositiveInt and PositiveFloat settings.
- Add support for Django 1.11.
- Implement basic settings classes.

0.2.0 (2017-04-17)
==================

- Implement basic Setting class.
- Pin dependencies.
- Change distribution name to app-settings.

0.1.0 (2017-03-23)
==================

- Alpha release on PyPI.
